#!/bin/bash
# basler-gentl-path.sh Copyright (c) 2017-2021 Basler AG
# Author: Bjoern Rennfanz <bjoern.rennfanz@baslerweb.com>
#
# File: /etc/profile.d/basler-gentl-path.sh
# 
# This script setups the GENICAM_GENTLXX_PATH variable
# on login depending on architecture of host system.
#

# Setup used variables
pylon_inst_dir="/opt/pylon"
basler_gentl_lib_dir="$pylon_inst_dir/lib/gentlproducer/gtl"
is_basler_gentl_64=""

# Detect bitness of system using uname
unamem="$(uname -m)"
if [[ $unamem == *aarch64* ]]; then
    is_basler_gentl_64=true
elif [[ $unamem == *64* ]]; then
    # only linux x86-64 supports CXP
    basler_gentl_lib_dir="$basler_gentl_lib_dir:$pylon_inst_dir/lib/pylonCXP/bin/"
    is_basler_gentl_64=true
elif [[ $unamem == *86* ]]; then
    is_basler_gentl_64=false
elif [[ $unamem == *armv5* ]]; then
    is_basler_gentl_64=false
elif [[ $unamem == *armv6l* ]]; then
    is_basler_gentl_64=false
elif [[ $unamem == *armv7l* ]]; then
    is_basler_gentl_64=false
fi

# Extend GenTL producer search path depending on architecture of host system.
if [ "$is_basler_gentl_64" = true ]; then
    export GENICAM_GENTL64_PATH=$GENICAM_GENTL64_PATH:$basler_gentl_lib_dir
else
    export GENICAM_GENTL32_PATH=$GENICAM_GENTL32_PATH:$basler_gentl_lib_dir
fi
